@@ -62,6 +62,10 @@
 #include <Plasma/Wallpaper>
 #include <Plasma/WindowEffects>
 
+#include <Nepomuk/ResourceManager>
+
+#include "../components/runnermodel/runnermodel.h"
+
 #include <X11/Xlib.h>
 #include <X11/extensions/Xrender.h>
 
@@ -79,6 +83,7 @@ PlasmaApp::PlasmaApp()
     : KUniqueApplication(),
       m_corona(0),
       m_mainView(0),
+      m_declarativeWidget(0),
       m_currentContainment(0),
       m_panelShadows(0),
       m_isDesktop(false)
@@ -88,6 +93,8 @@ PlasmaApp::PlasmaApp()
 
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
+    Nepomuk::ResourceManager::instance()->init();
+
     qmlRegisterType<PanelProxy>("org.kde.plasma.deviceshell", 0, 1, "DevicePanel");
 
     //FIXME: why does not work?
@@ -638,6 +645,7 @@ void PlasmaApp::containmentScreenOwnerChanged(int wasScreen, int isScreen, Plasm
 void PlasmaApp::gotStartup(const KStartupInfoId &id, const KStartupInfoData &data)
 {
     Q_UNUSED(id)
+    Q_UNUSED(data)
 
     if (!m_busyWidget) {
         m_busyWidget = new BusyWidget();
